@@ -1,16 +1,9 @@
-from . import base
-from . import registry
-from . import no_compression
-from . import gzip
-from . import bz2
-from . import lzma
-from . import zipfile
-from . import lz4
+from . import base, bz2, gzip, lz4, lzma, no_compression, registry, zipfile
 from .base import BaseCompresser
-from .registry import *
-from .no_compression import NoCompresser
-from .gzip import GzipCompresser
 from .bz2 import Bz2Compresser
-from .lzma import LzmaCompresser
-from .zipfile import ZipfileCompresser
+from .gzip import GzipCompresser
 from .lz4 import Lz4Compresser
+from .lzma import LzmaCompresser
+from .no_compression import NoCompresser
+from .registry import *
+from .zipfile import ZipfileCompresser
