@@ -1,9 +1,9 @@
-from typing import Any, IO
 import marshal
+from typing import IO, Any
+
 from .base import BasePicklerIO
 from .registry import register_pickler
 
-
 __all__ = ["MarshalPicklerIO"]
 
 
